pub enum FakeCrashReporterQuerierRequest {
WatchFile {
responder: FakeCrashReporterQuerierWatchFileResponder,
},
}Expand description
FakeCrashReporterQuerier provides a way to query a fake crash reporter component to ensure that crash reports are being filed as expected.
Variants
WatchFile
Returns the number of reports that have been filed with the fake crash reporter ever.
This method follows the hanging-get pattern and won’t return a value until the number of reports filed since the last call has changed.
Fields

responder: FakeCrashReporterQuerierWatchFileResponderImplementations
Sourceimpl FakeCrashReporterQuerierRequest
impl FakeCrashReporterQuerierRequest
pub fn into_watch_file( self, ) -> Option<FakeCrashReporterQuerierWatchFileResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL