pub struct FakeCrashReporterQuerierProxy { /* private fields */ }Implementations
Sourceimpl FakeCrashReporterQuerierProxy
impl FakeCrashReporterQuerierProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.feedback.testing/FakeCrashReporterQuerier.
Sourcepub fn take_event_stream(&self) -> FakeCrashReporterQuerierEventStream
pub fn take_event_stream(&self) -> FakeCrashReporterQuerierEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn watch_file(&self) -> QueryResponseFut<u64, DefaultFuchsiaResourceDialect>
pub fn watch_file(&self) -> QueryResponseFut<u64, DefaultFuchsiaResourceDialect>
Returns the number of reports that have been filed with the fake crash reporter ever.
This method follows the hanging-get pattern and won’t return a value until the number of reports filed since the last call has changed.