#[repr(C)]pub struct FakeCrashReporterQuerierWatchFileResponse {
pub num_filed: u64,
}Fields
num_filed: u64Trait Implementations
Sourceimpl Clone for FakeCrashReporterQuerierWatchFileResponse
impl Clone for FakeCrashReporterQuerierWatchFileResponse
Sourcefn clone(&self) -> FakeCrashReporterQuerierWatchFileResponse
fn clone(&self) -> FakeCrashReporterQuerierWatchFileResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<FakeCrashReporterQuerierWatchFileResponse, D> for FakeCrashReporterQuerierWatchFileResponsewhere
D: ResourceDialect,
impl<D> Decode<FakeCrashReporterQuerierWatchFileResponse, D> for FakeCrashReporterQuerierWatchFileResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> FakeCrashReporterQuerierWatchFileResponse
fn new_empty() -> FakeCrashReporterQuerierWatchFileResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<FakeCrashReporterQuerierWatchFileResponse, D> for &FakeCrashReporterQuerierWatchFileResponsewhere
D: ResourceDialect,
impl<D> Encode<FakeCrashReporterQuerierWatchFileResponse, D> for &FakeCrashReporterQuerierWatchFileResponsewhere
D: ResourceDialect,
Sourceimpl Ord for FakeCrashReporterQuerierWatchFileResponse
impl Ord for FakeCrashReporterQuerierWatchFileResponse
Sourcefn cmp(&self, other: &FakeCrashReporterQuerierWatchFileResponse) -> Ordering
fn cmp(&self, other: &FakeCrashReporterQuerierWatchFileResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FakeCrashReporterQuerierWatchFileResponse
impl PartialEq for FakeCrashReporterQuerierWatchFileResponse
Sourcefn eq(&self, other: &FakeCrashReporterQuerierWatchFileResponse) -> bool
fn eq(&self, other: &FakeCrashReporterQuerierWatchFileResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for FakeCrashReporterQuerierWatchFileResponse
impl PartialOrd for FakeCrashReporterQuerierWatchFileResponse
Sourceimpl TypeMarker for FakeCrashReporterQuerierWatchFileResponse
impl TypeMarker for FakeCrashReporterQuerierWatchFileResponse
Sourcetype Owned = FakeCrashReporterQuerierWatchFileResponse
type Owned = FakeCrashReporterQuerierWatchFileResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for FakeCrashReporterQuerierWatchFileResponse
impl ValueTypeMarker for FakeCrashReporterQuerierWatchFileResponse
Sourcetype Borrowed<'a> = &'a FakeCrashReporterQuerierWatchFileResponse
type Borrowed<'a> = &'a FakeCrashReporterQuerierWatchFileResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<FakeCrashReporterQuerierWatchFileResponse as TypeMarker>::Owned,
) -> <FakeCrashReporterQuerierWatchFileResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<FakeCrashReporterQuerierWatchFileResponse as TypeMarker>::Owned, ) -> <FakeCrashReporterQuerierWatchFileResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for FakeCrashReporterQuerierWatchFileResponse
impl Eq for FakeCrashReporterQuerierWatchFileResponse
impl Persistable for FakeCrashReporterQuerierWatchFileResponse
impl StructuralPartialEq for FakeCrashReporterQuerierWatchFileResponse